==> ec2-0.21.0-sources.jar: software/amazon/awscdk/services/ec2/WindowsImage.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Select the latest version of the indicated Windows version
 * 
 * The AMI ID is selected using the values published to the SSM parameter store.
 * 
 * https://aws.amazon.com/blogs/mt/query-for-the-latest-windows-ami-using-systems-manager-parameter-store/
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:30:41.785Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.WindowsImage")
public class WindowsImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImageSource {
    protected WindowsImage(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public WindowsImage(final software.amazon.awscdk.services.ec2.WindowsVersion version) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(java.util.Objects.requireNonNull(version, "version is required")).toArray());
    }

    /**
     * Return the image to use in the given context
     */
    @Override
    public software.amazon.awscdk.services.ec2.MachineImage getImage(final software.amazon.awscdk.Construct parent) {
        return this.jsiiCall("getImage", software.amazon.awscdk.services.ec2.MachineImage.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")).toArray());
    }

    public software.amazon.awscdk.services.ec2.WindowsVersion getVersion() {
        return this.jsiiGet("version", software.amazon.awscdk.services.ec2.WindowsVersion.class);
    }
}

==> ec2-0.22.0-sources.jar: software/amazon/awscdk/services/ec2/WindowsImage.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Select the latest version of the indicated Windows version
 * 
 * The AMI ID is selected using the values published to the SSM parameter store.
 * 
 * https://aws.amazon.com/blogs/mt/query-for-the-latest-windows-ami-using-systems-manager-parameter-store/
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.13 (build 311bf88)", date = "2019-01-11T10:48:43.572Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.WindowsImage")
public class WindowsImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImageSource {
    protected WindowsImage(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public WindowsImage(final software.amazon.awscdk.services.ec2.WindowsVersion version) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(java.util.Objects.requireNonNull(version, "version is required")).toArray());
    }

    /**
     * Return the image to use in the given context
     */
    @Override
    public software.amazon.awscdk.services.ec2.MachineImage getImage(final software.amazon.awscdk.Construct scope) {
        return this.jsiiCall("getImage", software.amazon.awscdk.services.ec2.MachineImage.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")).toArray());
    }

    public software.amazon.awscdk.services.ec2.WindowsVersion getVersion() {
        return this.jsiiGet("version", software.amazon.awscdk.services.ec2.WindowsVersion.class);
    }
}
